package com.nisum.Employeeinfo.controller;

import com.nisum.Employeeinfo.dto.EmployeeDto;
import com.nisum.Employeeinfo.mapper.EmployeeMapper;
import com.nisum.Employeeinfo.model.Employee;
import com.nisum.Employeeinfo.service.EmployeeService;
import com.nisum.Employeeinfo.service.EmployeeServiceImpl;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import reactor.core.publisher.Flux;
import reactor.core.publisher.Mono;

@RestController
@RequestMapping("/employee")
public class EmployeeController {

    @Autowired
    private EmployeeService employeeService;

    private static  final Logger log= LoggerFactory.getLogger(EmployeeController.class);

    @PostMapping("/addEmployee")
    public Mono<ResponseEntity<Employee>> addEmployee(@RequestBody Mono<EmployeeDto> mono){
        return employeeService.addEmployee(mono)
                .map(ResponseEntity::ok);


    }
    @GetMapping("/getEmployeeById/{id}")
    public Mono<Employee> getEmployeeById(@PathVariable Integer id){

        return employeeService.getEmployeeById(id)
                .doOnNext(employee -> log.info("received employee {}",employee));
    }

    @GetMapping("/getAllEmployee")
    public Flux<Employee> getAllEmployee(){
        return employeeService.getAllEmployee()
                .doOnNext(employee -> log.info("received all employee {}", employee));

    }

    @PutMapping("/{id}/updateEmployee")
    public Mono<Employee> updateEmployee(@PathVariable Integer id, @RequestBody Mono<EmployeeDto> updatedEmployee){

        return employeeService.updateEmployee(id,updatedEmployee);
    }

    @DeleteMapping("/deleteMapping/{id}")
    public Mono<Void> deleteEmployee(@PathVariable Integer id){

        return employeeService.deleteEmployee(id);
    }
}
